Structs
- Activity
- User activity record
- Closed
Position - Closed position record
- Combo
Activity - A combo lifecycle or redeem event.
- Combo
Event - Event metadata attached to a combo leg’s market.
- Combo
Leg - A single leg of a combinatorial position.
- Combo
Market - Market metadata attached to a combo leg.
- Combo
Position - A combinatorial (multi-market) position held by a user.
- Combos
Activity Response - Response envelope for
GET /v1/activity/combos. - Combos
Response - Response envelope for
GET /v1/positions/combos. - Market
Position V1 - A per-user position in a single market, as returned by
/v1/market-positions. - Meta
Market Position V1 - Market positions grouped by outcome token.
- Open
Interest - Open interest for a market
- Other
Size - “Other” outcome size held by a user in an augmented neg-risk event.
- Pagination
- Standard pagination metadata for combo endpoints.
- PnlPoint
- A single point on a user’s PnL curve.
- Position
- User position in a market
- Ranking
Entry - One entry in a volume or profit ranking.
- Revision
Entry - A single moderated revision of a question.
- Revision
Payload - Moderated revisions for a question.
- Trade
- Trade record
- User
Value - User’s total position value
Enums
- Activity
Sort By - Sort field options for activity queries
- Activity
Type - Activity type
- Closed
Position Sort By - Sort field options for closed position queries
- Combo
LegStatus - Resolution state of a single leg within a combinatorial position.
- Combo
Sort - Sort order for
crate::api::combos::ListComboPositions. - Combo
Status - Resolution state of a combinatorial position.
- Market
Position Sort By - Sort field options for
/v1/market-positions. - Market
Position Status - Status filter for
/v1/market-positions. - PnlFidelity
- Sampling resolution for a PnL series.
- Position
Sort By - Sort field options for position queries
- Ranking
Window - Ranking window for the rankings host.
- Sort
Direction - Sort direction for queries
- Time
Period - Time period for aggregation
- Trade
Filter Type - Filter type for trade queries
- Trade
Side - Trade side (buy or sell)